import { AxiosInstance } from "axios";
export default class CardFunctions {
    axios: AxiosInstance;
    constructor(axios: AxiosInstance);
    createCard(board_id: string, column_id: string, name: string, position: number, labels: [{
        id: string;
        name: string;
    }], members: [{
        id: string;
    }]): Promise<Card>;
    deleteCard(board_id: string, card_id: string): Promise<void>;
    archiveCard(board_id: string, card_id: string): Promise<void>;
    getCards(board_id: string, options: {
        archived: boolean | null;
        fields: [CardFields];
    }): Promise<[{
        column_id: string;
        card_counts: {
            unarchived: number;
            archived: number;
        };
        cards: [Card];
    }]>;
    getArchivedCards(board_id: string, options: {
        fields: [CardFields];
    }): Promise<[{
        column_id: string;
        card_counts: {
            unarchived: number;
            archived: number;
        };
        cards: [Card];
    }]>;
    addAndRemoveAssignees(board_id: string, card_id: string, added: [{
        id: string;
    }] | [], removed: [{
        id: string;
    }] | []): Promise<{
        errors: [string];
        id: string;
        members: [{
            id: string;
        }];
    }>;
    addAssignees(board_id: string, card_id: string, assignees: [{
        id: string;
    }]): Promise<{
        errors: [string];
        id: string;
        members: [{
            id: string;
        }];
    }>;
    addAssignee(board_id: string, card_id: string, user_id: string): Promise<{
        errors: [string];
        id: string;
        members: [{
            id: string;
        }];
    }>;
    removeAssignees(board_id: string, card_id: string, assignees: [{
        id: string;
    }]): Promise<{
        errors: [string];
        id: string;
        members: [{
            id: string;
        }];
    }>;
    removeAssignee(board_id: string, card_id: string, user_id: string): Promise<{
        errors: [string];
        id: string;
        members: [{
            id: string;
        }];
    }>;
}
export declare type CardFields = keyof Card;
export declare type Card = {
    attachment_count: number;
    board_id: string;
    column_id: string;
    comment_count: number;
    completed_task_count: number;
    created_by: string;
    created_date: string;
    description: null | {
        created_by: string;
        created_date: string;
        text: string;
        updated_date: string;
        user: {
            id: string;
            name: string;
        };
    };
    id: string;
    labels: [string];
    members: [string];
    name: string;
    total_task_count: number;
    updated_date: string;
};
